@@ -1,4 +1,6 @@
-__VERSION__ = "1.1.9"
+import os
+
+__VERSION__ = "1.2.0"
 __version__ = __VERSION__
 
 ASSAY_DICT = {
@@ -15,3 +17,4 @@ ASSAY_DICT = {
     'citeseq': 'Single Cell CITE-Seq',
     'tcr_fl': 'Single Cell full length TCR',
 }
+ROOT_PATH = os.path.dirname(__file__)
