@@ -1,23 +1,23 @@
-from celescope.fusion.__init__ import __STEPS__, __ASSAY__
-from celescope.tools.Multi import Multi
+from celescope.fusion.__init__ import __ASSAY__
+from celescope.tools.multi import Multi
 
 
 class Multi_fusion(Multi):
 
-    def STAR_fusion(self, sample):
-        step = 'STAR_fusion'
+    def star_fusion(self, sample):
+        step = 'star_fusion'
         cmd_line = self.get_cmd_line(step, sample)
-        input_read = f'{self.outdir_dic[sample]["cutadapt"]}/{sample}_clean_2.fq{self.fq_suffix}'
+        fq = f'{self.outdir_dic[sample]["cutadapt"]}/{sample}_clean_2.fq{self.fq_suffix}'
         cmd = (
             f'{cmd_line} '
-            f'--input_read {input_read} '
+            f'--fq {fq} '
         )
         self.process_cmd(cmd, step, sample, m=self.args.starMem, x=self.args.thread)
 
     def count_fusion(self, sample):
         step = 'count_fusion'
         cmd_line = self.get_cmd_line(step, sample)
-        bam = f'{self.outdir_dic[sample]["STAR_fusion"]}/{sample}_Aligned.sortedByCoord.out.bam'
+        bam = f'{self.outdir_dic[sample]["star_fusion"]}/{sample}_Aligned.sortedByCoord.out.bam'
         cmd = (
             f'{cmd_line} '
             f'--bam {bam} '
