@@ -2,8 +2,8 @@ __STEPS__ = [
     'sample',
     'barcode',
     'cutadapt',
-    'STAR',
-    "STAR_virus",
+    'star',
+    "star_virus",
     "featureCounts",
     "count",
     "count_virus",
