@@ -1,11 +1,11 @@
-from celescope.snp.__init__ import __STEPS__, __ASSAY__
-from celescope.tools.Multi import Multi
+from celescope.snp.__init__ import __ASSAY__
+from celescope.tools.multi import Multi
 
 
 class Multi_snp(Multi):
 
-    def STAR(self, sample):
-        step = 'STAR'
+    def star(self, sample):
+        step = 'star'
         cmd_line = self.get_cmd_line(step, sample)
         if self.args.not_consensus:
             fq = f'{self.outdir_dic[sample]["cutadapt"]}/{sample}_clean_2.fq{self.fq_suffix}'
@@ -22,7 +22,7 @@ class Multi_snp(Multi):
     def target_metrics(self, sample):
         step = 'target_metrics'
         cmd_line = self.get_cmd_line(step, sample)
-        bam = f'{self.outdir_dic[sample]["featureCounts"]}/{sample}_name_sorted.bam'
+        bam = f'{self.outdir_dic[sample]["featureCounts"]}/{sample}_Aligned.sortedByCoord.out.bam.featureCounts.bam'
         cmd = (
             f'{cmd_line} '
             f'--bam {bam} '
@@ -34,7 +34,7 @@ class Multi_snp(Multi):
     def snpCalling(self, sample):
         step = 'snpCalling'
         cmd_line = self.get_cmd_line(step, sample)
-        bam = f'{self.outdir_dic[sample]["featureCounts"]}/{sample}_name_sorted.bam'
+        bam = f'{self.outdir_dic[sample]["target_metrics"]}/{sample}_filtered.bam'
         cmd = (
             f'{cmd_line} '
             f'--bam {bam} '
