@@ -1,20 +1,11 @@
-#!/bin/env python
-# coding=utf8
-
 import os
-import sys
-import json
-import logging
-import re
-import numpy as np
+import subprocess
+
 import pandas as pd
-import glob
-from scipy.io import mmwrite
-from scipy.sparse import csr_matrix
-from celescope.tools.utils import *
-from celescope.rna.__init__ import __ASSAY__
-from celescope.tools.analysisMixin import AnalysisMixin 
-from celescope.tools.Step import Step
+
+from celescope.tools.utils import add_log, gene_convert, s_common
+from celescope.tools.analysis_mixin import AnalysisMixin 
+from celescope.tools.step import Step
 
 
 TOOLSDIR = os.path.dirname(__file__)
@@ -42,7 +33,7 @@ def seurat(sample, outdir, matrix_file, save_rds):
         f'--save_rds {save_rds}'
     )
     seurat.logger.info(cmd)
-    os.system(cmd)
+    subprocess.check_call(cmd, shell=True)
 
 
 @add_log
@@ -57,7 +48,7 @@ def auto_assign(sample, outdir, type_marker_tsv):
         f'--sample {sample} '
     )
     auto_assign.logger.info(cmd)
-    os.system(cmd)
+    subprocess.check_call(cmd, shell=True)
 
 
 class Analysis_rna(Step, AnalysisMixin):
