@@ -14,8 +14,7 @@ from xopen import xopen
 
 import celescope.tools.utils as utils
 from celescope.tools.__init__ import __PATTERN_DICT__
-from celescope.tools.Chemistry import Chemistry
-from celescope.tools.Step import Step, s_common
+from celescope.tools.step import Step, s_common
 
 
 MIN_T = 10
@@ -178,6 +177,88 @@ def check_seq_mismatch(seq_list, correct_set_list, mismatch_dict_list):
     return bool_valid, bool_corrected, corrected_seq
 
 
+class Chemistry():
+    """
+    Auto detect chemistry from read 1
+    """
+
+    def __init__(self, fq1):
+        self.fq1 = fq1
+        self.fq1_list = fq1.split(',')
+        self.nRead = 10000
+
+    @utils.add_log
+    def check_chemistry(self):
+        chemistry_list = []
+        for fastq1 in self.fq1_list:
+            print(fastq1)
+            chemistry = self.get_chemistry(fastq1)
+            chemistry_list.append(chemistry)
+        if len(set(chemistry_list)) != 1:
+            Chemistry.check_chemistry.logger.warning('multiple chemistry found!' + str(chemistry_list))
+        return chemistry_list
+
+    @utils.add_log
+    def get_chemistry(self, fq1):
+        '''
+        'scopeV2.0.1': 'C8L16C8L16C8L1U8T18'
+        'scopeV2.1.1': 'C8L16C8L16C8L1U12T18'
+        'scopeV2.2.1': 'C8L16C8L16C8L1U12T18' with 4 types of linkers
+        '''
+        # init
+        linker_4_file, _whitelist = get_scope_bc('scopeV2.2.1')
+        linker_4_list, _num = utils.read_one_col(linker_4_file)
+        linker_4_dict = defaultdict(int)
+        linker_wrong_dict = defaultdict(int)
+        pattern_dict = parse_pattern('C8L16C8L16C8L1U12T18')
+        T4_n = 0
+        L57C_n = 0
+
+        with pysam.FastxFile(fq1) as fh:
+            for _ in range(self.nRead):
+                entry = fh.__next__()
+                seq = entry.sequence
+                L57C = seq[56]
+                if L57C == 'C':
+                    L57C_n += 1
+                T4 = seq[65:69]
+                if T4 == 'TTTT':
+                    T4_n += 1
+                linker = seq_ranges(seq, pattern_dict=pattern_dict['L'])
+                if linker in linker_4_list:
+                    linker_4_dict[linker] += 1
+                else:
+                    linker_wrong_dict[linker] += 1
+
+        percent_T4 =  T4_n / self.nRead 
+        percent_L57C = L57C_n / self.nRead
+        Chemistry.get_chemistry.logger.info(f'percent T4: {percent_T4}')
+        Chemistry.get_chemistry.logger.info(f'percent L57C: {percent_L57C}')
+        if percent_T4 > 0.5:
+            chemistry = 'scopeV2.0.1'
+        else:
+            # V2.1.1 or V2.2.1 or failed
+            valid_linker_type = 0
+            for linker in linker_4_dict:
+                linker_4_dict[linker] = linker_4_dict[linker] / self.nRead
+                if linker_4_dict[linker] > 0.05:
+                    valid_linker_type += 1
+            Chemistry.get_chemistry.logger.info(linker_4_dict)
+            if valid_linker_type == 0:
+                print(linker_wrong_dict)
+                raise Exception('auto chemistry detection failed!')
+            elif valid_linker_type == 1:
+                chemistry = 'scopeV2.1.1'
+            elif valid_linker_type < 4:
+                chemistry = 'scopeV2.2.1'
+                Chemistry.get_chemistry.logger.warning(
+                    f'chemistry scopeV2.2.1 only has {valid_linker_type} linker types!')
+            else:
+                chemistry = 'scopeV2.2.1'
+        Chemistry.get_chemistry.logger.info(f'chemistry: {chemistry}')
+        return chemistry
+
+
 class Barcode(Step):
 
     '''barcode step class
@@ -217,7 +298,7 @@ class Barcode(Step):
             self.bool_probe = True
             self.probe_count_dic = utils.genDict(dim=3)
             self.valid_count_dic = utils.genDict(dim=2)
-            self.probe_dic = utils.read_fasta(args.probe_file)
+            self.probe_dic, _ = utils.read_fasta(args.probe_file)
             self.reads_without_probe = 0
         self.pattern = args.pattern
         self.linker = args.linker
@@ -353,7 +434,7 @@ class Barcode(Step):
                 umi = seq_ranges(seq1, pattern_dict['U'])
 
                 self.clean_num += 1
-
+                '''
                 if self.bool_probe:
                     # valid count
                     read_name_probe = 'None'
@@ -372,7 +453,7 @@ class Barcode(Step):
 
                     if not find_probe:
                         self.reads_without_probe += 1
-
+                '''
                 self.barcode_qual_Counter.update(C_U_quals_ascii[:C_len])
                 self.umi_qual_Counter.update(C_U_quals_ascii[C_len:])
 
@@ -486,7 +567,7 @@ def get_opts_barcode(parser, sub_program=True):
     parser.add_argument('--allowNoLinker', help="allow reads without correct linker", action='store_true')
     parser.add_argument('--gzip', help="output gzipped fastq", action='store_true')
     parser.add_argument(
-        '--chemistry', choices=__PATTERN_DICT__.keys(), help='chemistry version', default='auto')
+        '--chemistry', choices=list(__PATTERN_DICT__.keys()), help='chemistry version', default='auto')
     if sub_program:
         parser.add_argument('--fq1', help='read1 fq file', required=True)
         parser.add_argument('--fq2', help='read2 fq file', required=True)
