@@ -3,17 +3,13 @@
 
 import os
 import re
-import logging
 import subprocess
-import glob
-import sys
 import pysam
-from celescope.tools.utils import *
-from celescope.tools.report import reporter
-from celescope.tools.Step import Step
+from celescope.tools.utils import add_log, format_number, gene_convert, glob_genomeDir, s_common
+from celescope.tools.step import Step
 
 
-def format_stat(log, samplename):
+def format_stat(log):
     #Assigned, Unassigned_NoFeatures, Unassigned_Ambiguity=(0, 0, 0)
     tmp_arr = []
     fh = open(log, 'r')
@@ -77,20 +73,20 @@ def featureCounts(args):
 
     # check
     if args.genomeDir and args.genomeDir != "None":
-        _refFlat, gtf = glob_genomeDir(args.genomeDir)
+        _refFlat, gtf, _ = glob_genomeDir(args.genomeDir)
     else:
         gtf = args.gtf
 
     # run featureCounts
     outPrefix = args.outdir + '/' + args.sample
     cmd = [
-        'featureCounts', 
+        'featureCounts',
         '-s', '1',
-        '-a', gtf, 
-        '-o', outPrefix, 
+        '-a', gtf,
+        '-o', outPrefix,
         '-R', 'BAM',
-        '-T', str(args.thread), 
-        '-t', args.gtf_type, 
+        '-T', str(args.thread),
+        '-t', args.gtf_type,
         args.input,
     ]
     featureCounts.logger.info('%s' % (' '.join(cmd)))
@@ -105,7 +101,7 @@ def featureCounts(args):
     add_tag(bam, gtf)
 
     # sort by name:BC and umi
-    featureCounts.logger.info('samtools sort ...!')
+    featureCounts.logger.info('samtools sort by name...!')
     cmd = [
         'samtools',
         'sort',
@@ -118,9 +114,9 @@ def featureCounts(args):
         bam]
     featureCounts.logger.info('%s' % (' '.join(cmd)))
     subprocess.check_call(cmd)
-    featureCounts.logger.info('samtools sort done.')
+    featureCounts.logger.info('samtools sort sort by name done.')
 
-    format_stat(args.outdir + '/' + args.sample + '.summary', args.sample)
+    format_stat(args.outdir + '/' + args.sample + '.summary')
 
     step.clean_up()
 
